import { createStore } from 'vuex'
import axios from 'axios'

const API_URL = 'http://localhost:8000/api'

// Add axios interceptors for debugging
axios.interceptors.request.use(request => {
  console.log('Starting Request:', request.url, request.headers)
  return request
})

axios.interceptors.response.use(
  response => {
    console.log('Response:', response.data)
    return response
  },
  error => {
    console.error('API Error:', error.response?.data || error.message)
    return Promise.reject(error)
  }
)

const store = createStore({
  state: {
    token: localStorage.getItem('token') || null,
    todos: []
  },
  mutations: {
    setToken(state, token) {
      state.token = token
    },
    setTodos(state, todos) {
      state.todos = todos
    },
    addTodo(state, todo) {
      state.todos.push(todo)
    },
    updateTodo(state, updatedTodo) {
      const index = state.todos.findIndex(todo => todo.id === updatedTodo.id)
      if (index !== -1) {
        state.todos.splice(index, 1, updatedTodo)
      }
    },
    removeTodo(state, todoId) {
      state.todos = state.todos.filter(todo => todo.id !== todoId)
    }
  },
  actions: {
    async login({ commit }, credentials) {
      try {
        const response = await axios.post(`${API_URL}/login/`, credentials)
        const token = response.data.token
        localStorage.setItem('token', token)
        commit('setToken', token)
        return true
      } catch (error) {
        console.error('Login error:', error)
        return false
      }
    },
    async register({ commit }, credentials) {
      try {
        const response = await axios.post(`${API_URL}/register/`, credentials)
        const token = response.data.token
        localStorage.setItem('token', token)
        commit('setToken', token)
        return true
      } catch (error) {
        console.error('Registration error:', error)
        return false
      }
    },
    logout({ commit }) {
      localStorage.removeItem('token')
      commit('setToken', null)
      commit('setTodos', [])
    },
    async fetchTodos({ commit, state }) {
      try {
        console.log('Fetching todos with token:', state.token)
        const response = await axios.get(`${API_URL}/todos/`, {
          headers: { Authorization: `Bearer ${state.token}` }
        })
        commit('setTodos', response.data)
      } catch (error) {
        console.error('Error fetching todos:', error)
        if (error.response?.status === 401) {
          commit('setToken', null)
          localStorage.removeItem('token')
        }
        throw error
      }
    },
    async addTodo({ commit, state }, title) {
      try {
        console.log('Adding todo:', title)
        const response = await axios.post(
          `${API_URL}/todos/`,
          { title },
          {
            headers: {
              Authorization: `Bearer ${state.token}`,
              'Content-Type': 'application/json'
            }
          }
        )
        commit('addTodo', response.data)
      } catch (error) {
        console.error('Error adding todo:', error)
        throw error
      }
    },
    async updateTodo({ commit, state }, todo) {
      try {
        const response = await axios.put(
          `${API_URL}/todos/${todo.id}/`,
          todo,
          {
            headers: {
              Authorization: `Bearer ${state.token}`,
              'Content-Type': 'application/json'
            }
          }
        )
        commit('updateTodo', response.data)
      } catch (error) {
        console.error('Error updating todo:', error)
        throw error
      }
    },
    async deleteTodo({ commit, state }, todoId) {
      try {
        await axios.delete(
          `${API_URL}/todos/${todoId}/`,
          {
            headers: {
              Authorization: `Bearer ${state.token}`,
              'Content-Type': 'application/json'
            }
          }
        )
        commit('removeTodo', todoId)
      } catch (error) {
        console.error('Error deleting todo:', error)
        throw error
      }
    }
  },
  getters: {
    isAuthenticated: state => !!state.token,
    todos: state => state.todos
  }
})

export default store
